==> libreoffice-4.3.2.2.tar.xz: libreoffice-4.3.2.2/sw/source/core/layout/objstmpconsiderwrapinfl.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include <objstmpconsiderwrapinfl.hxx>
#include <anchoredobject.hxx>

SwObjsMarkedAsTmpConsiderWrapInfluence::SwObjsMarkedAsTmpConsiderWrapInfluence()
{
}

SwObjsMarkedAsTmpConsiderWrapInfluence::~SwObjsMarkedAsTmpConsiderWrapInfluence()
{
    Clear();
}

void SwObjsMarkedAsTmpConsiderWrapInfluence::Insert( SwAnchoredObject& _rAnchoredObj )
{

    bool bAlreadyInserted( false );
    std::vector< SwAnchoredObject* >::const_iterator aIter = maObjsTmpConsiderWrapInfl.begin();
    for ( ; aIter != maObjsTmpConsiderWrapInfl.end(); ++aIter )
    {
        const SwAnchoredObject* pAnchoredObj = *(aIter);
        if ( pAnchoredObj == &_rAnchoredObj )
        {
            bAlreadyInserted = true;
            break;
        }
    }

    if ( !bAlreadyInserted )
    {
        maObjsTmpConsiderWrapInfl.push_back( &_rAnchoredObj );
    }
}

void SwObjsMarkedAsTmpConsiderWrapInfluence::Clear()
{
    while ( maObjsTmpConsiderWrapInfl.size() )
    {
        SwAnchoredObject* pAnchoredObj = maObjsTmpConsiderWrapInfl.back();
        pAnchoredObj->SetTmpConsiderWrapInfluence( false );
        pAnchoredObj->SetClearedEnvironment( false );

        maObjsTmpConsiderWrapInfl.pop_back();
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */

==> libreoffice_6.0.3.orig.tar.xz: libreoffice-6.0.3/sw/source/core/layout/objstmpconsiderwrapinfl.cxx <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
/*
 * This file is part of the LibreOffice project.
 *
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 *
 * This file incorporates work covered by the following license notice:
 *
 *   Licensed to the Apache Software Foundation (ASF) under one or more
 *   contributor license agreements. See the NOTICE file distributed
 *   with this work for additional information regarding copyright
 *   ownership. The ASF licenses this file to you under the Apache
 *   License, Version 2.0 (the "License"); you may not use this file
 *   except in compliance with the License. You may obtain a copy of
 *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
 */

#include "objstmpconsiderwrapinfl.hxx"
#include <anchoredobject.hxx>

SwObjsMarkedAsTmpConsiderWrapInfluence::SwObjsMarkedAsTmpConsiderWrapInfluence()
{
}

SwObjsMarkedAsTmpConsiderWrapInfluence::~SwObjsMarkedAsTmpConsiderWrapInfluence()
{
    Clear();
}

void SwObjsMarkedAsTmpConsiderWrapInfluence::Insert( SwAnchoredObject& _rAnchoredObj )
{

    bool bAlreadyInserted( false );
    std::vector< SwAnchoredObject* >::const_iterator aIter = maObjsTmpConsiderWrapInfl.begin();
    for ( ; aIter != maObjsTmpConsiderWrapInfl.end(); ++aIter )
    {
        const SwAnchoredObject* pAnchoredObj = *aIter;
        if ( pAnchoredObj == &_rAnchoredObj )
        {
            bAlreadyInserted = true;
            break;
        }
    }

    if ( !bAlreadyInserted )
    {
        maObjsTmpConsiderWrapInfl.push_back( &_rAnchoredObj );
    }
}

void SwObjsMarkedAsTmpConsiderWrapInfluence::Clear()
{
    while ( maObjsTmpConsiderWrapInfl.size() )
    {
        SwAnchoredObject* pAnchoredObj = maObjsTmpConsiderWrapInfl.back();
        pAnchoredObj->SetTmpConsiderWrapInfluence( false );
        pAnchoredObj->SetClearedEnvironment( false );

        maObjsTmpConsiderWrapInfl.pop_back();
    }
}

/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
